@@ -2,9 +2,11 @@ from django.conf import settings
 
 from qtdjango.helpers import get_resource_name_for_model, get_all_models
 from piston.resource import Resource
-from handlers import create_handler_type
+from handlers import create_handler_type, InfoHandler
 from django.conf.urls.defaults import url, patterns
 
+
+
 def create_resource(model):
     """Builds resource from model class
     @param model: Model class"""
@@ -14,8 +16,15 @@ def create_resource(model):
 def get_url_pattens(app_list):
     """Gets app list returns urls patterns"""
     models = get_all_models(app_list, from_django=True)
-    urlpatterns = [url(r"^"+get_resource_name_for_model(model),\
-            create_resource(model)) for model in models]
+    urlpatterns = []
+    models_list = []
+    for model in models:
+        urlpatterns.append(url(r"^"+get_resource_name_for_model(model),\
+            create_resource(model)))
+
+    InfoHandler.set_models(models)
+    urlinfo = url(r"^info", Resource(InfoHandler))
+    urlpatterns.append(urlinfo)
 
 
     return patterns("", * urlpatterns)
