@@ -21,6 +21,7 @@ def istype(obj, typename):
 
 class Field(object):
     widget = None
+    always_read_only = False
     def __init__(self, verbose_name=None, *args, **kwargs):
         try:
             self.verbose_name = verbose_name
@@ -44,13 +45,27 @@ class Field(object):
         self.__read_only.append(model_class)
 
     def is_read_only_in(self, model_class):
-        return model_class in self.__read_only
+        return model_class in self.__read_only or self.always_read_only
 
     def to_raw(self, data):
         return data
 
     def to_text(self, data):
-        return unicode(data)
+        if data is None:
+            return u"<пусто>"
+        else:
+            return unicode(data)
+
+    def validate(self, data, model_instance):
+        print data, self
+        if data is None or data=="":
+            if self.blank or self.null or self.is_read_only_in(model_instance.__class__):
+                return None
+            else:
+                return u"Поле не может быть пустым"
+        else:
+            return None
+
 
     def get_blank(self):
         return None
@@ -63,6 +78,7 @@ class Field(object):
 
 
 class IdField(Field):
+    always_read_only = True
     def __init__(self, *args, **kwargs):
         super(IdField, self).__init__(*args, **kwargs)
         self.read_only = True
@@ -96,6 +112,12 @@ class BooleanField(Field):
     def to_raw(self, data):
         return data
 
+    def to_text(self, data):
+        if data:
+            return u"да"
+        else:
+            return u"нет"
+
 class EmailField(CharField):
     pass
     def to_raw(self, data):
@@ -137,8 +159,8 @@ class ForeignKey(RelField):
                 return data
         else:
             return None
-    def to_text(self, data):
-        return unicode(data)
+#    def to_text(self, data):
+#        return unicode(data)
 
     def to_raw(self, data):
         try:
@@ -224,13 +246,12 @@ class Model(object):
                 raise ResourceNameError
             cls.id = IdField("Id")
             raw = cls.__models_manager.get_resource_from_server(cls.resource_name)
-            cls.objects = []
-            cls.views = []
-            cls.max_negative_undumped_id = -1
-            """@cvar Current maximal undumped id"""
+
+
             for x in raw:
                 o = cls(**x)
                 o.__dumped=True
+                o.version = cls.version
                 cls.objects.append(o)
             cls.loaded = True
     #FIXME
@@ -250,6 +271,7 @@ class Model(object):
         @param models_manager: ModelsManager object
         """
         cls.__models_manager = models_manager
+        cls.views = []
         for method in cls.exclude_methods:
             setattr(cls, method, getattr(Model, method))
 
@@ -268,6 +290,10 @@ class Model(object):
             setattr(field.model, cls.__name__.lower()+"_set",
                     lambda inst: cls.filter(**{fieldname:inst}))
 
+    @classmethod
+    def flush(cls):
+        cls.objects = []
+        cls.loaded = False
 
 
     @classmethod
@@ -315,8 +341,7 @@ class Model(object):
         """Used only from user code. Returns new model instance"""
         o = cls(**kwargs)
         o.__dumped = False
-        o.id = cls.max_negative_undumped_id
-        cls.max_negative_undumped_id-=1
+        o.id = cls.max_negative_undumped_id()
         cls.objects.append(o)
         return o
 
@@ -355,7 +380,8 @@ class Model(object):
     @classmethod
     def get_fields(cls):
         """
-        Returns dict of class Fields
+        Returns dict of class Fields           self.refresh()
+
         """
         f = {}
         for fieldname in dir(cls):
@@ -441,6 +467,13 @@ class Model(object):
         return self.__valid
 
 
+    def validate(self):
+        result = {}
+        for fieldname, field in self.get_fields().items():
+            result[fieldname]=field.validate(getattr(self, fieldname), self)
+        return result
+
+
     @classmethod
     def is_all_dumped(cls):
         """
@@ -472,6 +505,7 @@ class Model(object):
     @classmethod
     def notify(cls):
         """Sends notify to all views, connected to model"""
+        print "notify", cls, cls.views
         for v in cls.views:
             v.refresh()
         if not cls.is_all_dumped():
@@ -499,6 +533,14 @@ class Model(object):
         """
         return ""
 
+    @classmethod
+    def max_negative_undumped_id(cls):
+        max = 0
+        for o in cls.objects:
+            if o.id<max:
+                max = o.id
+        return max+1
+
 
 class User(Model):
     #Todo: implement django behavoir
