@@ -3,6 +3,7 @@
 
 import sys
 import os
+import pickle
 from helpers import get_all_models
 from qtdjango.models import Model
 from qtdjango.connection import Connection
@@ -23,7 +24,7 @@ class ModelsManager(object):
         @param login: login to django server
         @param password: password to django server
         """
-        self.__connection = Connection(server, url, login, password)
+        self.set_connection_params(server, url, login, password)
         self.models = self.__get_registered_models(path_to_django_project,\
                 app_list, exclude_model_names)
         self.notify_dumped = []
@@ -35,13 +36,54 @@ class ModelsManager(object):
         self.models.sort(cmp=Model.is_model_depend_on)
 
         for m in self.models:
+            m.version = 0
             m.init_model_class(models_manager=self)
-        for model in self.models:
-            model.load()
-        for model in self.models:
-            model.refresh_foreing_keys()
 
+    def set_connection_params(self, server, url, login, password):
+        self.__connection = Connection(server, url, login, password)
 
+    def load_from_server(self):
+        try:
+            for model in self.models:
+                model.flush()
+            for model in self.models:
+                model.version += 1
+
+                model.load()
+            for model in self.models:
+                model.refresh_foreing_keys()
+            for model in self.models:
+                model.notify()
+        except:
+            return False
+        finally:
+            for func in self.notify_dumped:
+                func()
+        return True
+
+    def save_to_file(self, file):
+        """
+        Saves current modelmanager state to file
+        """
+        objs = {}
+        for model in self.models:
+            objs[model.__name__] = model.objects
+        pickle.dump(objs, file)
+
+    def load_from_file(self, file):
+        """
+        Loads modelmanager state from file
+        """
+        objs = pickle.load(file)
+
+        for model in self.models:
+            model.objects = objs[model.__name__]
+            model.notify()
+            print model.all()
+        if not self.is_all_dumped():
+            self.notify_changes()
+
+        return True
 
 
     def add_notify_dumped(self, function):
